@@ -69,7 +69,7 @@ except Exception:
     AUTH = True
 
 
-class DaapZeroconfInterface(GObject.GObject):
+class DaapZeroconfInterface(GObject.Object):
     __gsignals__ = {
         'connect': (GObject.SignalFlags.RUN_LAST, None, (GObject.TYPE_PYOBJECT,))
     }
@@ -186,7 +186,7 @@ class DaapZeroconfInterface(GObject.GObject):
         """
         Sets up the zeroconf listener.
         """
-        GObject.GObject.__init__(self)
+        GObject.Object.__init__(self)
         self.services = {}
         self.menu = _menu
 
@@ -735,7 +735,7 @@ class DaapClientPlugin:
         menu_ = menu.Menu(None)
 
         providers.register(
-            'menubar-tools-menu', _sep('plugin-sep', ['track-properties'])
+            'menubar-tools-menu', _sep('plugin-sep', ['slow-scan-collection'])
         )
 
         item = _smi('daap', ['plugin-sep'], _('Connect to DAAP...'), submenu=menu_)
