@@ -188,7 +188,7 @@ for i, a in enumerate(
     setattr(Anchor, a, Anchor(i))
 
 
-class Marker(GObject.GObject):
+class Marker(GObject.Object):
     """
     A marker pointing to a playback position
     """
@@ -235,8 +235,8 @@ class Marker(GObject.GObject):
     }
     __gsignals__ = {'reached': (GObject.SignalFlags.RUN_LAST, None, ())}
 
-    def __init__(self, position=0):
-        GObject.GObject.__init__(self)
+    def __init__(self, position: float = 0):
+        GObject.Object.__init__(self)
 
         self.__values = {
             'anchor': Anchor.SOUTH,
@@ -318,14 +318,12 @@ class MarkerManager(providers.ProviderHandler):
         for e in self.__events:
             event.remove_callback(getattr(self, 'on_%s' % e), e)
 
-    def add_marker(self, position):
+    def add_marker(self, position: float) -> Marker:
         """
         Creates a new marker for a playback position
 
         :param position: the playback position [0..1]
-        :type position: float
         :returns: the new marker
-        :rtype: :class:`Marker`
         """
         marker = Marker(position)
         # Provider compatibility
@@ -334,12 +332,11 @@ class MarkerManager(providers.ProviderHandler):
 
         return marker
 
-    def remove_marker(self, marker):
+    def remove_marker(self, marker: Marker) -> None:
         """
         Removes a playback marker
 
         :param marker: the marker
-        :type marker: :class:`Marker`
         """
         providers.unregister('playback-markers', marker)
 
@@ -446,7 +443,7 @@ class _SeekInternalProgressBar(PlaybackProgressBar):
             context.close_path()
 
             if marker.props.state in (Gtk.StateType.PRELIGHT, Gtk.StateType.ACTIVE):
-                c = style.get_color(Gtk.StateType.NORMAL)
+                c = style.get_color(Gtk.StateFlags.NORMAL)
                 context.set_source_rgba(c.red, c.green, c.blue, c.alpha)
             else:
                 if marker.props.color is not None:
@@ -463,7 +460,7 @@ class _SeekInternalProgressBar(PlaybackProgressBar):
             context.fill_preserve()
 
             if marker.props.state in (Gtk.StateType.PRELIGHT, Gtk.StateType.ACTIVE):
-                c = style.get_color(Gtk.StateType.NORMAL)
+                c = style.get_color(Gtk.StateFlags.NORMAL)
                 context.set_source_rgba(c.red, c.green, c.blue, c.alpha)
             else:
                 foreground = style.get_color(marker.props.state)
